@@ -169,7 +169,8 @@ class BuildDjango:
                 print("    queryset = {}.objects.all().order_by('id')".format(line))
                 print("    serializer_class = {}Serializer".format(line))
                 print("    permission_classes = (IsAuthenticated,)")
-                print("    authentication_classes = (TokenAuthentication,)")
+                # print("    authentication_classes = (TokenAuthentication,)")
+                print("    authentication_classes = (ExpiringTokenAuthentication,)")
             row = row + 1
 
     # 首字母小写
@@ -856,7 +857,7 @@ class BuildDjango:
                 count_index += 1
         item["item"] = sub_item_list
 
-        self.append_json(self.postmanFile, item)
+        self.append_json(self.postmanEncrptFile, item)
         # items_list.append(item)
         # postman_json["item"].append(item)
         # file = open(self.postmanFile, "w", encoding='utf-8')
@@ -957,7 +958,7 @@ class BuildDjango:
         return_value = aESEncryption.AES_en(return_value)
         return_value = StringHexMutualConvertion.convert_str_to_hex(return_value)
         # "{\r\n    \"data\": \"75705951776675496763713672756b6c55623832574e4e565672797a2f666b5853445a493662707a2b536a63482b5159414c5038717055636156625a32347376616862642f567a454b4773415a52375a786230444b62564637706f545736366c6c6f6766724c4e42703442773134747145466d70316e31427561794c51714f77646b524e793246795558655069317a495843457642773d3d\"\r\n}",
-        return "{\r\n    \"data\"\"" + return_value + "\"\r\n}"
+        return "{\r\n    \"data\":\"" + return_value + "\"\r\n}"
 
     # 生成viewer里增删改查的重载方法模板代码
     def generate_cude_code_in_viewer(self, api_path, table_cname, table_class, not_same_field_cn_list,
@@ -966,232 +967,265 @@ class BuildDjango:
         line_break_str = "\r\n"
 
         # create方法重载
-        create_code_str = "def create(self, request, *args, **kwargs):"
-        create_code_str += "{}api_path = \"{}\"".format(tab_str, api_path)
-        create_code_str += "{}try:{}".format(tab_str, line_break_str)
-        create_code_str += "{}{}function_title = \"新增{}\"{}".format(tab_str, tab_str, table_cname, line_break_str)
-        create_code_str += "{}{}start = LoggerHelper.set_start_log_info(logger){}".format(tab_str, tab_str,
-                                                                                          line_break_str)
-        info = ""
-        for index in range(len(not_same_field_cn_list)):
-            not_same_field_cn = not_same_field_cn_list[index]
-            not_same_field_en = not_same_field_en_list[index]
-            info += "{} {}".format(not_same_field_cn, not_same_field_en) + ","
-        info += " 不能重名"
-        create_code_str += "{}{}#{}{}".format(tab_str, tab_str, info, line_break_str)
+        create_code_str = "{}def create(self, request, *args, **kwargs):{}".format(tab_str, line_break_str)
+        create_code_str += "{}{}api_path = \"{}\"{}".format(tab_str, tab_str, api_path, line_break_str)
+        create_code_str += "{}{}try:{}".format(tab_str, tab_str, line_break_str)
+        create_code_str += "{}{}{}function_title = \"新增{}\"{}".format(tab_str, tab_str, tab_str, table_cname,
+                                                                        line_break_str)
+        create_code_str += "{}{}{}start = LoggerHelper.set_start_log_info(logger){}".format(tab_str, tab_str, tab_str,
 
-        for index in range(len(not_same_field_en_list)):
-            not_same_field_en = not_same_field_en_list[index]
-            info = "{} = request.data[\"{}\"] if \"{}\" in request.data else None".format(not_same_field_en,
-                                                                                          not_same_field_en,
-                                                                                          not_same_field_en)
-            create_code_str += "{}{}{}{}".format(tab_str, tab_str, info, line_break_str)
+                                                                                            line_break_str)
+        tab_str_5s = "\t\t\t\t\t"
+        tab_str_4s = "\t\t\t\t"
+        tab_str_3s = "\t\t\t"
+        need_tab_strs = ""
+        if not_same_field_cn_list is not None:
+            need_tab_strs = tab_str_4s
+            info = ""
+            for index in range(len(not_same_field_cn_list)):
+                not_same_field_cn = not_same_field_cn_list[index]
+                not_same_field_en = not_same_field_en_list[index]
+                info += "{} {}".format(not_same_field_cn, not_same_field_en) + ","
+            info += " 不能重名"
+            create_code_str += "{}{}{}#{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
 
-        for index in range(len(not_same_field_en_list)):
-            not_same_field_en = not_same_field_en_list[index]
-            not_same_field_cn = not_same_field_cn_list[index]
-            info = "if {} is not None and len({}.objects.filter({}={})) > 0:".format(not_same_field_en, table_class,
-                                                                                     not_same_field_en,
-                                                                                     not_same_field_en)
-            create_code_str += "{}{}{}{}".format(tab_str, tab_str, info, line_break_str)
-            info = "error_info = \"新增{}里的{}:{{}}已存在，请换个{}\".format({})".format(table_cname, not_same_field_cn,
-                                                                                         not_same_field_cn,
+            for index in range(len(not_same_field_en_list)):
+                not_same_field_en = not_same_field_en_list[index]
+                info = "{} = request.data[\"{}\"] if \"{}\" in request.data else None".format(not_same_field_en,
+                                                                                              not_same_field_en,
+                                                                                              not_same_field_en)
+                create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
+
+            for index in range(len(not_same_field_en_list)):
+                not_same_field_en = not_same_field_en_list[index]
+                not_same_field_cn = not_same_field_cn_list[index]
+                info = "if {} is not None and len({}.objects.filter({}={})) > 0:".format(not_same_field_en, table_class,
+                                                                                         not_same_field_en,
                                                                                          not_same_field_en)
-            create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
-            info = "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.license2.user, request,function_title, error_info, None)"
-            create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
-            create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, "return Response(res)", line_break_str)
+                create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
+                info = "error_info = \"新增{}里的{}:{{}}已存在，请换个{}\".format({})".format(table_cname,
+                                                                                             not_same_field_cn,
+                                                                                             not_same_field_cn,
+                                                                                             not_same_field_en)
+                create_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
+                info = "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.auth.user, request,function_title, error_info, None)"
+                create_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
+                create_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, "return Response(res)",
+                                                         line_break_str)
 
-        create_code_str += "{}{}{}{}".format(tab_str, tab_str, "else:", line_break_str)
+            create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, "else:", line_break_str)
+        else:
+            need_tab_strs = tab_str_3s
+
+        create_code_str += "{}{}{}".format(need_tab_strs,
+                                           "request.data[\"create_user_id\"] = request.auth.user_id",
+                                           line_break_str)
+        create_code_str += "{}{}{}".format(need_tab_strs,
+                                           "request.data[\"create_time\"] = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')",
+                                           line_break_str)
+        create_code_str += "{}{}{}".format(need_tab_strs,
+                                           "request.data[\"modify_user_id\"] = request.auth.user_id",
+                                           line_break_str)
+        create_code_str += "{}{}{}".format(need_tab_strs,
+                                           "request.data[\"modify_time\"] = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')",
+                                           line_break_str)
+        create_code_str += "{}{}{}".format(need_tab_strs,
+                                           "super().create(request)",
+                                           line_break_str)
+        create_code_str += "{}{}{}".format(need_tab_strs,
+                                           "LoggerHelper.set_end_log_info(logger, start, api_path, request.auth.user,request,function_title)",
+                                           line_break_str)
+        create_code_str += "{}{}{}".format(need_tab_strs,
+                                           "res = {'success': True,'info': \"{}成功\".format(function_title)}",
+                                           line_break_str)
+        create_code_str += "{}{}{}".format(need_tab_strs,
+                                           "return Response(res)", line_break_str)
+        create_code_str += "{}{}{}{}".format(tab_str, tab_str,
+                                             "except Exception as exp:", line_break_str)
         create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
-                                               " request.data[\"create_user_id\"] = request.license2.user_id",
-                                               line_break_str)
-        create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
-                                               "request.data[\"create_time\"] = vgis_datetime.vgis_datetime.now().strftime('%Y-%m-%d %H:%M:%S')",
-                                               line_break_str)
-        create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
-                                               "request.data[\"modify_user_id\"] = request.license2.user_id",
-                                               line_break_str)
-        create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
-                                               "request.data[\"modify_time\"] = vgis_datetime.vgis_datetime.now().strftime('%Y-%m-%d %H:%M:%S')",
-                                               line_break_str)
-        create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
-                                               "LoggerHelper.set_end_log_info(logger, start, api_path, request.license2.user,request,function_title)",
-                                               line_break_str)
-        create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
-                                               "res = {'success': True,'info': \"{}成功\".format(function_title)}",
+                                               "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.auth.user, request,function_title, None, exp)",
                                                line_break_str)
         create_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
                                                "return Response(res)", line_break_str)
-        create_code_str += "{}{}{}".format(tab_str,
-                                           "except Exception as exp:", line_break_str)
-        create_code_str += "{}{}{}{}".format(tab_str, tab_str,
-                                             "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.license2.user, request,function_title, None, exp)",
-                                             line_break_str)
-        create_code_str += "{}{}{}{}".format(tab_str, tab_str,
-                                             "return Response(res)", line_break_str)
 
         print(create_code_str)
 
         # update方法重载
-        update_code_str = "def update(self, request, *args, **kwargs):"
-        update_code_str += "{}api_path = \"{}\"".format(tab_str, api_path)
-        update_code_str += "{}try:{}".format(tab_str, line_break_str)
-        update_code_str += "{}{}function_title = \"更新{}\"{}".format(tab_str, tab_str, table_cname, line_break_str)
-        update_code_str += "{}{}start = LoggerHelper.set_start_log_info(logger){}".format(tab_str, tab_str,
-                                                                                          line_break_str)
-        info = ""
-        for index in range(len(not_same_field_cn_list)):
-            not_same_field_cn = not_same_field_cn_list[index]
-            not_same_field_en = not_same_field_en_list[index]
-            info += "{} {}".format(not_same_field_cn, not_same_field_en) + ","
-        info += " 不能重名"
-        update_code_str += "{}{}#{}{}".format(tab_str, tab_str, info, line_break_str)
-
-        update_code_str += "{}{}#{}{}".format(tab_str, tab_str, "id = kwargs[\"pk\"]", line_break_str)
+        update_code_str = "{}def update(self, request, *args, **kwargs):{}".format(tab_str, line_break_str)
+        update_code_str += "{}{}api_path = \"{}\"{}".format(tab_str, tab_str, api_path, line_break_str)
+        update_code_str += "{}{}try:{}".format(tab_str, tab_str, line_break_str)
+        update_code_str += "{}{}{}function_title = \"更新{}\"{}".format(tab_str, tab_str, tab_str, table_cname,
+                                                                        line_break_str)
+        update_code_str += "{}{}{}start = LoggerHelper.set_start_log_info(logger){}".format(tab_str, tab_str, tab_str,
+                                                                                            line_break_str)
+        update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, "id = kwargs[\"pk\"]", line_break_str)
+        if not_same_field_cn_list is not None:
+            info = ""
+            for index in range(len(not_same_field_cn_list)):
+                not_same_field_cn = not_same_field_cn_list[index]
+                not_same_field_en = not_same_field_en_list[index]
+                info += "{} {}".format(not_same_field_cn, not_same_field_en) + ","
+            info += " 不能重名"
+            update_code_str += "{}{}{}#{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
 
         info = "if len({}.objects.filter(id=id)) > 0:".format(table_class)
-        update_code_str += "{}{}#{}{}".format(tab_str, tab_str, info, line_break_str)
+        update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
 
-        for index in range(len(not_same_field_en_list)):
-            not_same_field_en = not_same_field_en_list[index]
-            info = "old_{} = {}.objects.filter(id=id)[0].{}".format(not_same_field_en, table_class,
-                                                                    not_same_field_en)
-            update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
+        if not_same_field_cn_list is not None:
+            for index in range(len(not_same_field_en_list)):
+                not_same_field_en = not_same_field_en_list[index]
+                info = "old_{} = {}.objects.filter(id=id)[0].{}".format(not_same_field_en, table_class,
+                                                                        not_same_field_en)
+                update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
 
         info = "request.data[\"create_user_id\"] = {}.objects.filter(id=id)[0].create_user_id".format(table_class)
-        update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
+        update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
         info = "request.data[\"create_time\"] = {}.objects.filter(id=id)[0].create_time".format(table_class)
-        update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
-        info = "request.data[\"modify_user_id\"] = request.license2.user_id"
-        update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
-        info = "request.data[\"modify_time\"] = vgis_datetime.vgis_datetime.now().strftime('%Y-%m-%d %H:%M:%S')"
-        update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
+        update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
+        info = "request.data[\"modify_user_id\"] = request.auth.user_id"
+        update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
+        info = "request.data[\"modify_time\"] = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')"
+        update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
 
-        for index in range(len(not_same_field_en_list)):
-            not_same_field_en = not_same_field_en_list[index]
-            info = "new_{} = request.data[\"{}\"] if \"{}\" in request.data else None".format(not_same_field_en,
-                                                                                              not_same_field_en,
-                                                                                              not_same_field_en)
-            update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
+        if not_same_field_cn_list is not None:
+            for index in range(len(not_same_field_en_list)):
+                not_same_field_en = not_same_field_en_list[index]
+                info = "new_{} = request.data[\"{}\"] if \"{}\" in request.data else None".format(not_same_field_en,
+                                                                                                  not_same_field_en,
+                                                                                                  not_same_field_en)
+                update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
 
-        for index in range(len(not_same_field_en_list)):
-            not_same_field_en = not_same_field_en_list[index]
-            not_same_field_cn = not_same_field_cn_list[index]
-            info = "if new_{} is not None and old_{} != new_{} and len({}.objects.filter({}={})) > 0:".format(
-                not_same_field_en, not_same_field_en, not_same_field_en, table_class,
-                not_same_field_en,
-                not_same_field_en)
-            update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info, line_break_str)
-            info = "error_info = \"更新{}里的{}:{{}}已存在，请换个{}\".format({})".format(table_cname, not_same_field_cn,
-                                                                                         not_same_field_cn,
-                                                                                         not_same_field_en)
-            update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
-            info = "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.license2.user, request,function_title, error_info, None)"
-            update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
-            update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, "return Response(res)",
-                                                     line_break_str)
+        if not_same_field_cn_list is not None:
+            need_tab_strs = tab_str_5s
+            for index in range(len(not_same_field_en_list)):
+                not_same_field_en = not_same_field_en_list[index]
+                not_same_field_cn = not_same_field_cn_list[index]
+                info = "if new_{} is not None and old_{} != new_{} and len({}.objects.filter({}=new_{})) > 0:".format(
+                    not_same_field_en, not_same_field_en, not_same_field_en, table_class,
+                    not_same_field_en,
+                    not_same_field_en)
+                update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info, line_break_str)
+                info = "error_info = \"更新{}里的{}:{{}}已存在，请换个{}\".format({})".format(table_cname,
+                                                                                             not_same_field_cn,
+                                                                                             not_same_field_cn,
+                                                                                             "new_" + not_same_field_en)
+                update_code_str += "{}{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, tab_str, info,
+                                                           line_break_str)
+                info = "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.auth.user, request,function_title, error_info, None)"
+                update_code_str += "{}{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, tab_str, info,
+                                                           line_break_str)
+                update_code_str += "{}{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, tab_str,
+                                                           "return Response(res)",
+                                                           line_break_str)
+
+            update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, "else:", line_break_str)
+        else:
+            need_tab_strs = tab_str_4s
+        update_code_str += "{}{}{}".format(need_tab_strs,
+                                           "super().update(request, *args, **kwargs)",
+                                           line_break_str)
+        update_code_str += "{}{}{}".format(need_tab_strs,
+                                                   "LoggerHelper.set_end_log_info(logger, start, api_path, request.auth.user,request,function_title)",
+                                                   line_break_str)
+        update_code_str += "{}{}{}".format(need_tab_strs,
+                                                   "res = {'success': True,'info': \"{}成功\".format(function_title)}",
+                                                   line_break_str)
+        update_code_str += "{}{}{}".format(need_tab_strs,
+                                                   "return Response(res)", line_break_str)
 
-        update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, "else:", line_break_str)
-        update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str,
-                                                 "LoggerHelper.set_end_log_info(logger, start, api_path, request.license2.user,request,function_title)",
-                                                 line_break_str)
-        update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str,
-                                                 "res = {'success': True,'info': \"{}成功\".format(function_title)}",
-                                                 line_break_str)
-        update_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str,
-                                                 "return Response(res)", line_break_str)
-        update_code_str += "{}{}{}".format(tab_str,
-                                           "except Exception as exp:", line_break_str)
         update_code_str += "{}{}{}{}".format(tab_str, tab_str,
-                                             "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.license2.user, request,function_title, None, exp)",
-                                             line_break_str)
-        update_code_str += "{}{}{}{}".format(tab_str, tab_str,
-                                             "return Response(res)", line_break_str)
+                                             "except Exception as exp:", line_break_str)
+        update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
+                                               "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.auth.user, request,function_title, None, exp)",
+                                               line_break_str)
+        update_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
+                                               "return Response(res)", line_break_str)
 
         print(update_code_str)
 
         #  根据编号查询详情方法重载
-        getdetail_code_str = "def get_object(self, *args, **kwargs):"
-        getdetail_code_str += "{}api_path = \"{}\"".format(tab_str, api_path)
-        getdetail_code_str += "{}try:{}".format(tab_str, line_break_str)
-        getdetail_code_str += "{}{}function_title = \"通过编号获取{}详情\"{}".format(tab_str, tab_str, table_cname,
-                                                                                     line_break_str)
-        getdetail_code_str += "{}{}start = LoggerHelper.set_start_log_info(logger){}".format(tab_str, tab_str,
-                                                                                             line_break_str)
-        getdetail_code_str += "{}{}result = \"\"{}".format(tab_str, tab_str,
-                                                           line_break_str)
-        info = "# 更新会进来"
+        getdetail_code_str = "{}def get_object(self, *args, **kwargs):{}".format(tab_str, line_break_str)
+        getdetail_code_str += "{}{}api_path = \"{}\"{}".format(tab_str, tab_str, api_path, line_break_str)
+        getdetail_code_str += "{}{}try:{}".format(tab_str, tab_str, line_break_str)
+        getdetail_code_str += "{}{}{}function_title = \"通过编号获取{}详情\"{}".format(tab_str, tab_str, tab_str,
+                                                                                       table_cname,
+                                                                                       line_break_str)
+        getdetail_code_str += "{}{}{}start = LoggerHelper.set_start_log_info(logger){}".format(tab_str, tab_str,
+                                                                                               tab_str,
+                                                                                               line_break_str)
+        getdetail_code_str += "{}{}{}result = \"\"{}".format(tab_str, tab_str, tab_str,
+                                                             line_break_str)
+        info = "#更新会进来"
         getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
                                                   line_break_str)
         info = "if self.action == \"update\":"
-        getdetail_code_str += "{}{}{}{}".format(tab_str, tab_str, info,
-                                                line_break_str)
+        getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
+                                                  line_break_str)
         info = "return super().get_object(*args, **kwargs)"
-        getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
-                                                  line_break_str)
+        getdetail_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info,
+                                                    line_break_str)
         info = "else:"
-        getdetail_code_str += "{}{}{}{}".format(tab_str, tab_str, info,
-                                                line_break_str)
+        getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
+                                                  line_break_str)
         info = "id=self.kwargs[\"pk\"]"
-        getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
-                                                  line_break_str)
+        getdetail_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info,
+                                                    line_break_str)
         info = "result = super().get_object(*args, **kwargs)"
-        getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
-                                                  line_break_str)
-        info = "LoggerHelper.set_end_log_info(logger, start, api_path + str(id), request.license2.user,request,function_title)"
-        getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
-                                                  line_break_str)
-        info = " return result"
-        getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
-                                                  line_break_str)
-        getdetail_code_str += "{}{}{}".format(tab_str,
-                                              "except Exception as exp:", line_break_str)
+        getdetail_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info,
+                                                    line_break_str)
+        info = "LoggerHelper.set_end_log_info(logger, start, api_path + str(id), self.request.auth.user,self.request,function_title)"
+        getdetail_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info,
+                                                    line_break_str)
+        info = "return result"
+        getdetail_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info,
+                                                    line_break_str)
         getdetail_code_str += "{}{}{}{}".format(tab_str, tab_str,
-                                                "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.license2.user, request,function_title, None, exp)",
-                                                line_break_str)
-        getdetail_code_str += "{}{}{}{}".format(tab_str, tab_str,
-                                                "return Response(res)", line_break_str)
+                                                "except Exception as exp:", line_break_str)
+        getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
+                                                  "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,self.request.auth.user, self.request,function_title, None, exp)",
+                                                  line_break_str)
+        getdetail_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
+                                                  "return Response(res)", line_break_str)
 
         print(getdetail_code_str)
 
         #  list方法重载
-        list_code_str = "def get_queryset(self, *args, **kwargs):"
-        list_code_str += "{}api_path = \"{}\"".format(tab_str, api_path)
-        list_code_str += "{}try:{}".format(tab_str, line_break_str)
-        list_code_str += "{}{}function_title = \"获取{}列表\"{}".format(tab_str, tab_str, table_cname,
-                                                                        line_break_str)
-        list_code_str += "{}{}start = LoggerHelper.set_start_log_info(logger){}".format(tab_str, tab_str,
-                                                                                        line_break_str)
+        list_code_str = "{}def get_queryset(self, *args, **kwargs):{}".format(tab_str, line_break_str)
+        list_code_str += "{}{}api_path = \"{}\"{}".format(tab_str, tab_str, api_path, line_break_str)
+        list_code_str += "{}{}try:{}".format(tab_str, tab_str, line_break_str)
+        list_code_str += "{}{}{}function_title = \"获取{}列表\"{}".format(tab_str, tab_str, tab_str, table_cname,
+                                                                          line_break_str)
+        list_code_str += "{}{}{}start = LoggerHelper.set_start_log_info(logger){}".format(tab_str, tab_str, tab_str,
+                                                                                          line_break_str)
         info = "# 更新和通过ID获取详情会进来"
-        list_code_str += "{}{}{}{}".format(tab_str, tab_str, info,
-                                           line_break_str)
+        list_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
+                                             line_break_str)
         info = "if \"pk\" in self.kwargs:"
-        list_code_str += "{}{}{}{}".format(tab_str, tab_str, info,
-                                           line_break_str)
+        list_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
+                                             line_break_str)
 
         info = "return super().get_queryset(*args, **kwargs)"
-        list_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
-                                             line_break_str)
+        list_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info,
+                                               line_break_str)
         info = "else:"
-        list_code_str += "{}{}{}{}".format(tab_str, tab_str, info,
-                                           line_break_str)
+        list_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
+                                             line_break_str)
         info = "querysets = super().get_queryset(*args, **kwargs)"
-        list_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
-                                             line_break_str)
-        info = "LoggerHelper.set_end_log_info(logger, start, api_path, request.license2.user,request,function_title)"
-        list_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
-                                             line_break_str)
-        info = " return querysets"
-        list_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str, info,
-                                             line_break_str)
-        list_code_str += "{}{}{}".format(tab_str,
-                                         "except Exception as exp:", line_break_str)
+        list_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info,
+                                               line_break_str)
+        info = "LoggerHelper.set_end_log_info(logger, start, api_path, self.request.auth.user,self.request,function_title)"
+        list_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info,
+                                               line_break_str)
+        info = "return querysets"
+        list_code_str += "{}{}{}{}{}{}".format(tab_str, tab_str, tab_str, tab_str, info,
+                                               line_break_str)
         list_code_str += "{}{}{}{}".format(tab_str, tab_str,
-                                           "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,request.license2.user, request,function_title, None, exp)",
-                                           line_break_str)
-        list_code_str += "{}{}{}{}".format(tab_str, tab_str,
-                                           "return Response(res)", line_break_str)
+                                           "except Exception as exp:", line_break_str)
+        list_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
+                                             "res = LoggerHelper.set_end_log_info_in_exception(logger, start, api_path,self.request.auth.user, self.request,function_title, None, exp)",
+                                             line_break_str)
+        list_code_str += "{}{}{}{}{}".format(tab_str, tab_str, tab_str,
+                                             "return Response(res)", line_break_str)
 
         print(list_code_str)
 
@@ -1244,6 +1278,32 @@ class BuildCode:
         print(code_str)
         return code_str
 
+    # if ExcelHelper.is_has_field_in_excel(excel_data_obj, "总序号"):
+    #     ocr_result["total_serial_number"] = excel_data_obj.values[row_index][
+    #         ExcelHelper.get_field_index_by_name_in_excel(excel_data_obj, "总序号")]
+    #     ocr_result["total_serial_number"] = ocr_result["total_serial_number"] if ocr_result[
+    #                                                                                  "total_serial_number"] is not None and str(
+    #         ocr_result["total_serial_number"]).strip() != "" else None
+    def create_snippt4(self, excel_obj_name, attribute_cnames_str, attribute_enames_str):
+        tab_str = "\t"
+        line_break_str = "\r\n"
+        code_str = ""
+        attribute_cname_list = attribute_cnames_str.split(",")
+        attribute_ename_list = attribute_enames_str.split(",")
+        for index in range(len(attribute_cname_list)):
+            attribute_cname = attribute_cname_list[index]
+            attribute_ename = attribute_ename_list[index]
+            temp_str = "if ExcelHelper.is_has_field_in_excel({}, \"{}\"):".format(excel_obj_name, attribute_cname)
+            code_str += temp_str + line_break_str
+            temp_str = "{}ocr_result[\"{}\"] = excel_data_obj.values[row_index][ExcelHelper.get_field_index_by_name_in_excel(excel_data_obj, \"{}\")]".format(
+                tab_str, attribute_ename, attribute_cname)
+            code_str += temp_str + line_break_str
+            temp_str = "{0}ocr_result[\"{1}\"] = ocr_result[\"{1}\"] if ocr_result[\"{1}\"] is not None and str(ocr_result[\"{1}\"]).strip() != \"\" else None".format(
+                tab_str, attribute_ename)
+            code_str += temp_str + line_break_str
+        print(code_str)
+        return code_str
+
 
 # 构建命令行参数
 def make_build_command():
